==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2015-10-19 10:28+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Führe Environment Prüfungen aus..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Keine {0} gefunden. Bitte überprüfen Sie ihre Filterkriterien, Ansichtsoptionen oder den/die {1}, in dem/der Sie suchen."

, "Check"
: "Teste"

, "Result"
: "Ergebnis"

, "Error"
: "Fehler"

, "Run setup tests"
: "Setup Tests ausführen"

, "Ignore setup tests"
: "Setuptests ignorieren"

, "Install application"
: "Anwendung installieren"

, "Terms and Conditions"
: "Bedingungen und Konditionen"

, "Setup Checks"
: "Setup Tests"

, "Config Manager"
: "Konfigurations-Verwaltung"

, "Authentication/Accounts"
: "Authentifizierung/Benutzerkonten"

, "Email"
: "Email"

, "Application Manager"
: "Anwendungs-Verwaltung"

, "I have read the license agreement and accept it"
: "Ich habe die Lizenzvereinbarung gelesen und akzeptiere sie"

, "License Agreement"
: "Lizenzvereinbarung"

, "I have read the privacy agreement and accept it"
: "Ich habe die Datenschutzvereinbarung gelesen und akzeptiere sie"

, "Privacy Agreement"
: "Datenschutzvereinbarung"

, "Accept Terms and Conditions"
: "Bedingungen und Konditionen akzeptieren"

, "Name"
: "Name"

, "Enabled"
: "Aktiviert"

, "Order"
: "Reihenfolge"

, "Installed Version"
: "Installierte Version"

, "Available Version"
: "Verfügbare Version"

, "Status"
: "Status"

, "Depends on"
: "Hängt ab von"

, "Uninstall application"
: "Anwendung deinstallieren"

, "Update application"
: "Anwendung aktualisieren"

, "Go to {0} login"
: "Zum {0} Login"

, "uninstall"
: "Deinstallieren"

, "Do you really want to uninstall the application(s)?"
: "Möchten Sie die Anwendung(en) wirklich deinstallieren?"

, "This may take a while"
: "Dies kann eine einige Zeit in Anspruch nehmen"

, "Dependency Violation"
: "Verletzung von Abhängigkeiten"

, "CLI Required"
: "CLI erforderlich"

, "Application, Applications"
: [
  "Anwendung"
 ,"Anwendungen"

]
, "Delete all existing users and groups"
: "Lösche alle existierenden Benutzer und Gruppen"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Der Wechsel von SQL nach LDAP wird alle bestehenden Benutzer, Gruppen und Rollen Löschen. Möchten sie den Wechsel wirklich vornehmen?"

, "Backend"
: "Backend"

, "TLS client certificate"
: "TLS Client-Zertifikat"

, "Initial Admin User"
: "Initialer Admin-Benutzer"

, "Initial admin login name"
: "Initialer Admin Loginname"

, "Initial admin Password"
: "Initiales Admin Password"

, "Password confirmation"
: "Passwort Bestätigung"

, "Authentication provider"
: "Authentifizierungsdienst"

, "Try to split username"
: "Versuche den Benutzernamen zu splitten"

, "Yes"
: "Ja"

, "No"
: "Nein"

, "Account canonical form"
: "Kanonische Form der Benutzerkonten"

, "Account domain name"
: "Kontodomänenname"

, "Account domain short name"
: "Account domain short name"

, "Host"
: "Host"

, "Port"
: "Port"

, "Login name"
: "Loginname"

, "Password"
: "Kennwort"

, "Bind requires DN"
: "Verbindung benötigt DN"

, "Start TLS"
: "Start TLS verwenden"

, "SSL"
: "SSL"

, "Base DN"
: "Base DN"

, "Search filter"
: "Suchfilter"

, "Hostname"
: "Hostname"

, "Secure Connection"
: "Sichere Verbindung"

, "None"
: "Keine"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Domäne an den Benutzernamen anhängen"

, "Certificate validation"
: "Zertifikatsvalidierung"

, "CA file"
: "CA Datei"

, "CRL directory"
: "CRL Verzeichnis"

, "Accounts storage"
: "Speicherort der Benutzerkonten"

, "Default user group name"
: "Standard Benutzer Gruppenname"

, "Default admin group name"
: "Standard Admin Gruppenname"

, "Login panel"
: "Anmeldebereich"

, "Reuse last username logged"
: "Den zuletzt benutzten Benutzernamen verwenden"

, "Password Settings"
: "Passworteinstellungen"

, "User can change password"
: "Benutzer kann Passwort ändern"

, "Enable password policy"
: "Passwortrichtlinie aktivieren"

, "Only ASCII"
: "Nur ASCII-Zeichen"

, "Minimum length"
: "Minimale Länge"

, "Minimum word chars"
: "Minimale Anzahl Wortzeichen"

, "Minimum uppercase chars"
: "Minimale Anzahl Großbuchstaben"

, "Minimum special chars"
: "Minimale Anzahl Sonderzeichen"

, "Minimum numbers"
: "Minimale Anzahl Zahlen"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Verbiete einen Teil des Benutzernamens im Passwort"

, "Redirect Settings"
: "Weiterleitungs Einstellungen"

, "Redirect Url (redirect to login screen if empty)"
: "Weiterleitungs-URL (Weiterleitung zum Login wenn leer)"

, "Redirect Always (if No, only redirect after logout)"
: "Immer Weiterleiten (Wenn Nein: nur nach dem ausloggen weiterleiten)"

, "Redirect to referring site, if exists"
: "Weiterleitung an die Herkunftsseite, falls eine existiert"

, "Password encoding"
: "Passwort Verschlüsselung"

, "des"
: "des"

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "Benutzer DN"

, "User Filter"
: "Benutzerfilter"

, "User Search Scope"
: "Benutzersuche-Bereich"

, "Groups DN"
: "Gruppen DN"

, "Group Filter"
: "Gruppenfilter"

, "Group Search Scope"
: "Gruppensuche-Bereich"

, "Use Rfc 2307 bis"
: "Benutze RFC2307bis"

, "Maintain RFC 2307 attributes"
: "RFC 2307-Attribute beibehalten"

, "Min User Id"
: "Minimale Benutzer Id"

, "Max User Id"
: "Maximale Benutzer Id"

, "Min Group Id"
: "Minimale Gruppen Id"

, "Max Group Id"
: "Maximale Gruppen Id"

, "Group UUID Attribute name"
: "UUID Attribut von Gruppen"

, "User UUID Attribute name"
: "UUID Attribut von Benutzerkonten"

, "Readonly access"
: "Nur lesender Zugriff"

, "Save config and install"
: "Konfiguration speichern und installieren"

, "Save config"
: "Konfiguration speichern"

, "Passwords don't match"
: "Die Passwörter stimmen nicht überein"

, "Should not be empty"
: "Darf nicht leer sein"

, "File"
: "Datei"

, "Setup Authentication"
: "Setup Authentifizierung"

, "Username"
: "Benutzername"

, "Database"
: "Datenbank"

, "User"
: "Benutzer"

, "Prefix"
: "Prefix"

, "Logging"
: "Logging"

, "Filename"
: "Dateiname"

, "Priority"
: "Priorität"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Lifetime (sekunden)"

, "Path"
: "Pfad"

, "Queue"
: "Queue"

, "Session"
: "Session"

, "Temporary files"
: "Flüchtige Dateien"

, "Temporary Files Path"
: "Pfad für flüchtige Dateien"

, "Filestore directory"
: "Datei-Ablage Verzeichnis"

, "Filestore Path"
: "Datei-Ablage Verzeichnis"

, "Addressbook Map panel"
: "Kartenfenster im Adressbuch"

, "Map panel"
: "Kartenfenster"

, "disabled"
: "deaktiviert"

, "enabled"
: "aktiviert"

, "Use Custom Theme"
: "Custom Theme verwenden"

, "Theme path"
: "Theme Pfad"

, "Use blue theme as base"
: "Verwende blaues Theme als Basis"

, "Config file is not writable"
: "Konfigurationsdatei nicht schreibbar"

, "Download config file"
: "Konfigurationsdatei herunterladen"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard  SMTP"

, "Imap"
: "Imap"

, "Use system account"
: "Systemkonto benutzen"

, "Use email address as login name"
: "E-Mail als Benutzername verwenden"

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Passwort"

, "Use proxy auth"
: "Proxy-Authentifizierung verwenden"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentifizierung"

, "Login"
: "Login"

, "Plain"
: "Klartext"

, "Primary Domain"
: "Primäre Domäne"

, "Secondary Domains (comma separated)"
: "Sekundäre Domänen (durch Komma getrennt)"

, "Notifications service address"
: "Notifikationsdienst Emailadresse"

, "Notification Username"
: "Benachrichtigungs-Benutzername"

, "Notification Password"
: "Benachrichtigungs-Passwort"

, "Notifications local client (hostname or IP address)"
: "Lokaler Hostname (oder IP-Adresse) für den Notifikationsdienst"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Datenbank"

, "MySql User"
: "MySql Benutzer"

, "MySql Password"
: "MySql Passwort"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Benutzer oder UID"

, "Group or GID"
: "Gruppe oder GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Passwortschema"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Message"
: "Informationen"

, "Application"
: "Anwendung"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-de-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2015-10-19 10:28+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: German (http://www.transifex.com/tine20/tine20/language/de/)\nLanguage: de\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Führe Environment Prüfungen aus..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Keine {0} gefunden. Bitte überprüfen Sie ihre Filterkriterien, Ansichtsoptionen oder den/die {1}, in dem/der Sie suchen."

, "Check"
: "Teste"

, "Result"
: "Ergebnis"

, "Error"
: "Fehler"

, "Run setup tests"
: "Setup Tests ausführen"

, "Ignore setup tests"
: "Setuptests ignorieren"

, "Install application"
: "Anwendung installieren"

, "Terms and Conditions"
: "Bedingungen und Konditionen"

, "Setup Checks"
: "Setup Tests"

, "Config Manager"
: "Konfigurations-Verwaltung"

, "Authentication/Accounts"
: "Authentifizierung/Benutzerkonten"

, "Email"
: "Email"

, "Application Manager"
: "Anwendungs-Verwaltung"

, "I have read the license agreement and accept it"
: "Ich habe die Lizenzvereinbarung gelesen und akzeptiere sie"

, "License Agreement"
: "Lizenzvereinbarung"

, "I have read the privacy agreement and accept it"
: "Ich habe die Datenschutzvereinbarung gelesen und akzeptiere sie"

, "Privacy Agreement"
: "Datenschutzvereinbarung"

, "Accept Terms and Conditions"
: "Bedingungen und Konditionen akzeptieren"

, "Name"
: "Name"

, "Enabled"
: "Aktiviert"

, "Order"
: "Reihenfolge"

, "Installed Version"
: "Installierte Version"

, "Available Version"
: "Verfügbare Version"

, "Status"
: "Status"

, "Depends on"
: "Hängt ab von"

, "Uninstall application"
: "Anwendung deinstallieren"

, "Update application"
: "Anwendung aktualisieren"

, "Go to {0} login"
: "Zum {0} Login"

, "uninstall"
: "Deinstallieren"

, "Do you really want to uninstall the application(s)?"
: "Möchten Sie die Anwendung(en) wirklich deinstallieren?"

, "This may take a while"
: "Dies kann eine einige Zeit in Anspruch nehmen"

, "Dependency Violation"
: "Verletzung von Abhängigkeiten"

, "CLI Required"
: "CLI erforderlich"

, "Application, Applications"
: [
  "Anwendung"
 ,"Anwendungen"

]
, "Delete all existing users and groups"
: "Lösche alle existierenden Benutzer und Gruppen"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Der Wechsel von SQL nach LDAP wird alle bestehenden Benutzer, Gruppen und Rollen Löschen. Möchten sie den Wechsel wirklich vornehmen?"

, "Backend"
: "Backend"

, "TLS client certificate"
: "TLS Client-Zertifikat"

, "Initial Admin User"
: "Initialer Admin-Benutzer"

, "Initial admin login name"
: "Initialer Admin Loginname"

, "Initial admin Password"
: "Initiales Admin Password"

, "Password confirmation"
: "Passwort Bestätigung"

, "Authentication provider"
: "Authentifizierungsdienst"

, "Try to split username"
: "Versuche den Benutzernamen zu splitten"

, "Yes"
: "Ja"

, "No"
: "Nein"

, "Account canonical form"
: "Kanonische Form der Benutzerkonten"

, "Account domain name"
: "Kontodomänenname"

, "Account domain short name"
: "Account domain short name"

, "Host"
: "Host"

, "Port"
: "Port"

, "Login name"
: "Loginname"

, "Password"
: "Kennwort"

, "Bind requires DN"
: "Verbindung benötigt DN"

, "Start TLS"
: "Start TLS verwenden"

, "SSL"
: "SSL"

, "Base DN"
: "Base DN"

, "Search filter"
: "Suchfilter"

, "Hostname"
: "Hostname"

, "Secure Connection"
: "Sichere Verbindung"

, "None"
: "Keine"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Domäne an den Benutzernamen anhängen"

, "Certificate validation"
: "Zertifikatsvalidierung"

, "CA file"
: "CA Datei"

, "CRL directory"
: "CRL Verzeichnis"

, "Accounts storage"
: "Speicherort der Benutzerkonten"

, "Default user group name"
: "Standard Benutzer Gruppenname"

, "Default admin group name"
: "Standard Admin Gruppenname"

, "Login panel"
: "Anmeldebereich"

, "Reuse last username logged"
: "Den zuletzt benutzten Benutzernamen verwenden"

, "Password Settings"
: "Passworteinstellungen"

, "User can change password"
: "Benutzer kann Passwort ändern"

, "Enable password policy"
: "Passwortrichtlinie aktivieren"

, "Only ASCII"
: "Nur ASCII-Zeichen"

, "Minimum length"
: "Minimale Länge"

, "Minimum word chars"
: "Minimale Anzahl Wortzeichen"

, "Minimum uppercase chars"
: "Minimale Anzahl Großbuchstaben"

, "Minimum special chars"
: "Minimale Anzahl Sonderzeichen"

, "Minimum numbers"
: "Minimale Anzahl Zahlen"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Verbiete einen Teil des Benutzernamens im Passwort"

, "Redirect Settings"
: "Weiterleitungs Einstellungen"

, "Redirect Url (redirect to login screen if empty)"
: "Weiterleitungs-URL (Weiterleitung zum Login wenn leer)"

, "Redirect Always (if No, only redirect after logout)"
: "Immer Weiterleiten (Wenn Nein: nur nach dem ausloggen weiterleiten)"

, "Redirect to referring site, if exists"
: "Weiterleitung an die Herkunftsseite, falls eine existiert"

, "Password encoding"
: "Passwort Verschlüsselung"

, "des"
: "des"

, "crypt"
: "crypt"

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "Benutzer DN"

, "User Filter"
: "Benutzerfilter"

, "User Search Scope"
: "Benutzersuche-Bereich"

, "Groups DN"
: "Gruppen DN"

, "Group Filter"
: "Gruppenfilter"

, "Group Search Scope"
: "Gruppensuche-Bereich"

, "Use Rfc 2307 bis"
: "Benutze RFC2307bis"

, "Maintain RFC 2307 attributes"
: "RFC 2307-Attribute beibehalten"

, "Min User Id"
: "Minimale Benutzer Id"

, "Max User Id"
: "Maximale Benutzer Id"

, "Min Group Id"
: "Minimale Gruppen Id"

, "Max Group Id"
: "Maximale Gruppen Id"

, "Group UUID Attribute name"
: "UUID Attribut von Gruppen"

, "User UUID Attribute name"
: "UUID Attribut von Benutzerkonten"

, "Readonly access"
: "Nur lesender Zugriff"

, "Save config and install"
: "Konfiguration speichern und installieren"

, "Save config"
: "Konfiguration speichern"

, "Passwords don't match"
: "Die Passwörter stimmen nicht überein"

, "Should not be empty"
: "Darf nicht leer sein"

, "File"
: "Datei"

, "Setup Authentication"
: "Setup Authentifizierung"

, "Username"
: "Benutzername"

, "Database"
: "Datenbank"

, "User"
: "Benutzer"

, "Prefix"
: "Prefix"

, "Logging"
: "Logging"

, "Filename"
: "Dateiname"

, "Priority"
: "Priorität"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Lifetime (sekunden)"

, "Path"
: "Pfad"

, "Queue"
: "Queue"

, "Session"
: "Session"

, "Temporary files"
: "Flüchtige Dateien"

, "Temporary Files Path"
: "Pfad für flüchtige Dateien"

, "Filestore directory"
: "Datei-Ablage Verzeichnis"

, "Filestore Path"
: "Datei-Ablage Verzeichnis"

, "Addressbook Map panel"
: "Kartenfenster im Adressbuch"

, "Map panel"
: "Kartenfenster"

, "disabled"
: "deaktiviert"

, "enabled"
: "aktiviert"

, "Use Custom Theme"
: "Custom Theme verwenden"

, "Theme path"
: "Theme Pfad"

, "Use blue theme as base"
: "Verwende blaues Theme als Basis"

, "Config file is not writable"
: "Konfigurationsdatei nicht schreibbar"

, "Download config file"
: "Konfigurationsdatei herunterladen"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "Standard IMAP"

, "Standard SMTP"
: "Standard  SMTP"

, "Imap"
: "Imap"

, "Use system account"
: "Systemkonto benutzen"

, "Use email address as login name"
: "E-Mail als Benutzername verwenden"

, "Cyrus Admin"
: "Cyrus Admin"

, "Cyrus Admin Password"
: "Cyrus Admin Passwort"

, "Use proxy auth"
: "Proxy-Authentifizierung verwenden"

, "Smtp"
: "Smtp"

, "Authentication"
: "Authentifizierung"

, "Login"
: "Login"

, "Plain"
: "Klartext"

, "Primary Domain"
: "Primäre Domäne"

, "Secondary Domains (comma separated)"
: "Sekundäre Domänen (durch Komma getrennt)"

, "Notifications service address"
: "Notifikationsdienst Emailadresse"

, "Notification Username"
: "Benachrichtigungs-Benutzername"

, "Notification Password"
: "Benachrichtigungs-Passwort"

, "Notifications local client (hostname or IP address)"
: "Lokaler Hostname (oder IP-Adresse) für den Notifikationsdienst"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "MySql Hostname"

, "MySql Database"
: "MySql Datenbank"

, "MySql User"
: "MySql Benutzer"

, "MySql Password"
: "MySql Passwort"

, "MySql Port"
: "MySql Port"

, "User or UID"
: "Benutzer oder UID"

, "Group or GID"
: "Gruppe oder GID"

, "Home Template"
: "Home Template"

, "Password Scheme"
: "Passwortschema"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Message"
: "Informationen"

, "Verify peer Certificate"
: ""

, "Setup"
: ""

, "Update applications"
: "Anwendungen aktualisieren"

, "Updating application, Updating applications"
: [
  "Aktualisiere Anwendung"
 ,"Aktualisiere Anwendungen"

]
, "Application"
: "Anwendung"

, "Updating application"
: "Aktualisiere Anwendung"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
